summaryrefslogtreecommitdiffstats
path: root/mbbsd/mail.c
diff options
context:
space:
mode:
Diffstat (limited to 'mbbsd/mail.c')
-rw-r--r--mbbsd/mail.c2
1 files changed, 1 insertions, 1 deletions
diff --git a/mbbsd/mail.c b/mbbsd/mail.c
index 9d6ff1e4..e01a0b68 100644
--- a/mbbsd/mail.c
+++ b/mbbsd/mail.c
@@ -1151,7 +1151,7 @@ mail_reply(int ent, fileheader_t * fhdr, const char *direct)
case 0:
/* success */
- if ( ent && /* for board, no ent */
+ if ( direct && /* for board, no direct */
(curredit & EDIT_MAIL) &&
!(fhdr->filemode & FILE_REPLIED))
{